<?php

namespace EventPortal\Domain\Event;

use EventPortal\Contracts\Event;
use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Event\Form\Models\Form;
use EventPortal\Domain\Event\Models\EventDelegate;
use EventPortal\Enums\InertiaMethod;
use Illuminate\Support\Arr;

class CallToAction
{
    /** @var \EventPortal\Contracts\Event */
    private $event;

    /** @var \EventPortal\Domain\Delegate\Models\Delegate */
    private $delegate;

    /** @var string */
    private $status;

    /** @var null|Form */
    private $registrationForm;

    /** @var bool */
    private $displayWhiteButton = false;

    public static function make(): self
    {
        return new self();
    }

    public function forEventAndDelegate(Event $event, Delegate $delegate): self
    {
        $this->event = $event;
        $this->delegate = $delegate;

        $this->status = EventDelegate::forEventAndDelegate($this->event, $this->delegate)
            ->firstOrFail()
            ->status;

        $this->registrationForm = Form::forEvent($this->event)->registration()->first();

        return $this;
    }

    public function forDelegate(Delegate $delegate): self
    {
        $this->delegate = $delegate;

        return $this;
    }

    public function asWhite(): self
    {
        $this->displayWhiteButton = true;

        return $this;
    }

    public function notWhite(): self
    {
        $this->displayWhiteButton = false;

        return $this;
    }

    /** Get the button */
    public function get(): ?Button
    {
        if ($this->registrationForm === null) {
            return null;
        }

        $button = Button::make($this->buttonLabel($this->status))
            ->icon('chevron-right', 'right')
            ->method(InertiaMethod::VISIT())
            ->route('delegate.form.index', [
                'event' => $this->event->slug,
                'form' => optional($this->registrationForm)->slug,
            ]);

        if ($button && $this->displayWhiteButton) {
            $button = $button->white();
        }

        return $button;
    }

    public function getAsArray(): array
    {
        return array_filter([$this->get()]);
    }

    private function buttonLabel(string $status): string
    {
        $labels = [
            'invited' => 'Begin registration',
            'registering' => 'Continue registration',
            'registered' => 'View registration details',
        ];

        return Arr::get($labels, $status, 'Begin registration');
    }
}
