<?php

namespace EventPortal\Tests\Feature\Admin\Email;

use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\Email\Models\EventEmail;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Event\Models\EventDelegate;
use EventPortal\Domain\Permission\Models\Permission;
use EventPortal\Http\Middleware\CurrentTeam;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Support\Arr;
use Spatie\Snapshots\MatchesSnapshots;

class EmailShowTest extends TestCase
{
    use DatabaseMigrations, MatchesSnapshots, SeedRolesAndPermissions;

    /** @test **/
    public function can_view_an_individual_email()
    {
        $admin = factory(Admin::class)->create();
        $event = factory(Event::class)->create([
            'name' => 'Hello World!',
        ]);
        $email = factory(EventEmail::class)->create([
            'event_id' => $event,
        ]);

        $admin->givePermissionTo([
            factory(Permission::class)->create([
                'name' => 'email.show',
            ]),
            factory(Permission::class)->create([
                'name' => 'email.update',
            ]),
        ]);

        $this->withoutMiddleware(CurrentTeam::class)
            ->assertMatchesJsonSnapshot(
                $this->actingAs($admin->user)
                    ->get(route('admin.email.show', [
                        'event' => $event->id,
                        'email' => $email->id,
                    ]))->props()
            );
    }

    /** @test **/
    public function can_count_previous_email_recipients()
    {
        $this->markTestIncomplete('Could do with a clearer way of checking the 3 delegates show up in the response.');

        $event = factory(Event::class)->create([
            'name' => 'Hello World!',
        ]);
        factory(EventDelegate::class, 3)->create([
            'event_id' => $event->id,
        ]);
        $email = factory(EventEmail::class)
            ->state('invite')
            ->create([
                'event_id' => $event,
            ]);

        $this
            ->withoutExceptionHandling()
            ->actingAsSuperAdmin()
            ->followingRedirects()
            ->post(route('admin.email.send', [
                'event' => $event,
                'email' => $email,
            ]))
            ->assertOk();

        $this->withoutMiddleware(CurrentTeam::class)
            ->assertMatchesJsonSnapshot(
                $this->actingAsSuperAdmin()
                    ->get(route('admin.email.show', [
                        'event' => $event->id,
                        'email' => $email->id,
                    ]))->props()
            );
    }
}
