<?php

namespace EventPortal\Tests\Feature\Admin\Team;

use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Team\Models\Team;
use EventPortal\Tests\Support\Traits\InteractsWithTeams;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;

class TeamPermissionsTest extends TestCase
{
    use DatabaseMigrations, InteractsWithTeams, SeedRolesAndPermissions;

    /** @test */
    public function a_user_cannot_view_events_from_other_teams()
    {
        $team1 = factory(Team::class)->create();
        [$team1Event, $team2Event] = factory(Event::class, 2)->create();
        $team1Admin = factory(Admin::class)->state('admin')->create();

        $this->addToSameTeam([$team1Admin, $team1Event], $team1);

        $this->actingAsAdmin($team1Admin)
            ->get(route('admin.event.show', $team1Event))
            ->assertOk();

        $this->get(route('admin.event.show', $team2Event))
            ->assertUnauthorized();
    }
}
